@@ -50,13 +50,14 @@ def _sample_conditional(
         # cov: [..., P, N, N]
         mean_for_sample = tf.linalg.adjoint(mean)  # [..., P, N]
         samples = sample_mvn(
-            mean_for_sample, cov, "full", num_samples=num_samples
+            mean_for_sample, cov, full_cov=True, num_samples=num_samples
         )  # [..., (S), P, N]
         samples = tf.linalg.adjoint(samples)  # [..., (S), N, P]
     else:
         # mean: [..., N, P]
         # cov: [..., N, P] or [..., N, P, P]
-        cov_structure = "full" if full_output_cov else "diag"
-        samples = sample_mvn(mean, cov, cov_structure, num_samples=num_samples)  # [..., (S), N, P]
+        samples = sample_mvn(
+            mean, cov, full_cov=full_output_cov, num_samples=num_samples
+        )  # [..., (S), N, P]
 
     return samples, mean, cov
