@@ -70,18 +70,19 @@ class ChangePoints(Combination):
         self.kernels = kernels
 
     def K(self, X: tf.Tensor, X2: Optional[tf.Tensor] = None) -> tf.Tensor:
-        sig_X = self._sigmoids(X)  # N x 1 x Ncp
-        sig_X2 = self._sigmoids(X2) if X2 is not None else sig_X
+        sig_X = self._sigmoids(X)  # N1 x 1 x Ncp
+        sig_X2 = self._sigmoids(X2) if X2 is not None else sig_X  # N2 x 1 x Ncp
 
         # `starters` are the sigmoids going from 0 -> 1, whilst `stoppers` go
-        # from 1 -> 0, dimensions are N x N x Ncp
+        # from 1 -> 0, dimensions are N1 x N2 x Ncp
         starters = sig_X * tf.transpose(sig_X2, perm=(1, 0, 2))
         stoppers = (1 - sig_X) * tf.transpose((1 - sig_X2), perm=(1, 0, 2))
 
         # prepend `starters` with ones and append ones to `stoppers` since the
         # first kernel has no start and the last kernel has no end
-        N = tf.shape(X)[0]
-        ones = tf.ones((N, N, 1), dtype=X.dtype)
+        N1 = tf.shape(X)[0]
+        N2 = tf.shape(X2)[0] if X2 is not None else N1
+        ones = tf.ones((N1, N2, 1), dtype=X.dtype)
         starters = tf.concat([ones, starters], axis=2)
         stoppers = tf.concat([stoppers, ones], axis=2)
 
