@@ -1,4 +1,4 @@
-from typing import Callable, Iterable, List, Tuple, Optional, TypeVar
+from typing import Callable, Iterable, List, Optional, Sequence, Tuple, TypeVar, Union
 
 import numpy as np
 import scipy.optimize
@@ -7,8 +7,8 @@ from scipy.optimize import OptimizeResult
 
 __all__ = ["Scipy"]
 
-Variables = Iterable[tf.Variable]
-StepCallback = Callable[[int, Variables, List[tf.Tensor]], None]
+Variables = Iterable[tf.Variable]  # deprecated
+StepCallback = Callable[[int, Sequence[tf.Variable], Sequence[tf.Tensor]], None]
 LossClosure = Callable[[], tf.Tensor]
 
 
@@ -16,7 +16,7 @@ class Scipy:
     def minimize(
         self,
         closure: LossClosure,
-        variables: Variables,
+        variables: Sequence[tf.Variable],
         method: Optional[str] = "L-BFGS-B",
         step_callback: Optional[StepCallback] = None,
         compile: bool = True,
@@ -34,20 +34,22 @@ class Scipy:
                 (typically `model.trainable_variables`)
             method: The type of solver to use in SciPy. Defaults to "L-BFGS-B".
             step_callback: If not None, a callable that gets called once after
-                each optimisation step. The callabe is passed the arguments
+                each optimisation step. The callable is passed the arguments
                 `step`, `variables`, and `values`. `step` is the optimisation
-                step counter. `variables` is the list of trainable variables as
+                step counter, `variables` is the list of trainable variables as
                 above, and `values` is the corresponding list of tensors of
                 matching shape that contains their value at this optimisation
                 step.
-            compile: If True, wraps the evaluation function (the passed `closure` as
-                well as its gradient computation) inside a `tf.function()`,
+            compile: If True, wraps the evaluation function (the passed `closure`
+                as well as its gradient computation) inside a `tf.function()`,
                 which will improve optimization speed in most cases.
 
             scipy_kwargs: Arguments passed through to `scipy.optimize.minimize`
+                Note that Scipy's minimize() takes a `callback` argument, but
+                you probably want to use our wrapper and pass in `step_callback`.
 
         Returns:
-            The optimization result represented as a scipy ``OptimizeResult``
+            The optimization result represented as a Scipy ``OptimizeResult``
             object. See the Scipy documentation for description of attributes.
         """
         if not callable(closure):
@@ -74,12 +76,12 @@ class Scipy:
         )
 
     @classmethod
-    def initial_parameters(cls, variables: Variables) -> tf.Tensor:
+    def initial_parameters(cls, variables: Sequence[tf.Variable]) -> tf.Tensor:
         return cls.pack_tensors(variables)
 
     @classmethod
     def eval_func(
-        cls, closure: LossClosure, variables: Variables, compile: bool = True
+        cls, closure: LossClosure, variables: Sequence[tf.Variable], compile: bool = True
     ) -> Callable[[np.ndarray], Tuple[np.ndarray, np.ndarray]]:
         def _tf_eval(x: tf.Tensor) -> Tuple[tf.Tensor, tf.Tensor]:
             values = cls.unpack_tensors(variables, x)
@@ -99,47 +101,51 @@ class Scipy:
 
     @classmethod
     def callback_func(
-        cls, variables: Variables, step_callback: StepCallback
+        cls, variables: Sequence[tf.Variable], step_callback: StepCallback
     ) -> Callable[[np.ndarray], None]:
         step = 0  # type: int
 
         def _callback(x: np.ndarray) -> None:
             nonlocal step
             values = cls.unpack_tensors(variables, x)
-            step_callback(step=step, variables=variables, values=values)
+            step_callback(step, variables, values)
             step += 1
 
         return _callback
 
     @staticmethod
-    def pack_tensors(tensors: Iterable[tf.Tensor]) -> tf.Tensor:
+    def pack_tensors(tensors: Sequence[Union[tf.Tensor, tf.Variable]]) -> tf.Tensor:
         flats = [tf.reshape(tensor, (-1,)) for tensor in tensors]
         tensors_vector = tf.concat(flats, axis=0)
         return tensors_vector
 
     @staticmethod
-    def unpack_tensors(to_tensors: Iterable[tf.Tensor], from_vector: tf.Tensor) -> List[tf.Tensor]:
+    def unpack_tensors(
+        to_tensors: Sequence[Union[tf.Tensor, tf.Variable]], from_vector: tf.Tensor
+    ) -> List[tf.Tensor]:
         s = 0
         values = []
-        for tensor in to_tensors:
-            shape = tf.shape(tensor)
+        for target_tensor in to_tensors:
+            shape = tf.shape(target_tensor)
+            dtype = target_tensor.dtype
             tensor_size = tf.reduce_prod(shape)
-            tensor_vector = tf.cast(from_vector[s : s + tensor_size], tensor.dtype)
-            tensor_vector = tf.reshape(tensor_vector, shape)
-            values.append(tensor_vector)
+            tensor_vector = from_vector[s : s + tensor_size]
+            tensor = tf.reshape(tf.cast(tensor_vector, dtype), shape)
+            values.append(tensor)
             s += tensor_size
         return values
 
     @staticmethod
-    def assign_tensors(to_tensors: Iterable[tf.Variable], values: Iterable[tf.Tensor]) -> None:
-        for tensor, tensor_vector in zip(to_tensors, values):
-            tensor.assign(tensor_vector)
+    def assign_tensors(to_tensors: Sequence[tf.Variable], values: Sequence[tf.Tensor]) -> None:
+        if len(to_tensors) != len(values):
+            raise ValueError("to_tensors and values should have same length")
+        for target, value in zip(to_tensors, values):
+            target.assign(value)
 
 
-V = TypeVar("V", bound=Variables)
-
-
-def _compute_loss_and_gradients(loss_closure: LossClosure, variables: V) -> Tuple[tf.Tensor, V]:
+def _compute_loss_and_gradients(
+    loss_closure: LossClosure, variables: Sequence[tf.Variable]
+) -> Tuple[tf.Tensor, Sequence[tf.Tensor]]:
     with tf.GradientTape(watch_accessed_variables=False) as tape:
         tape.watch(variables)
         loss = loss_closure()
